@@ -25,10 +25,23 @@ class SubsystemVisitor(PTNodeVisitor):
         name = ''.join(children)
         return name
 
+    def visit_class_name(self, node, children):
+        name = ''.join(children)
+        return {'name': name }
+
+    def visit_keyletter(self, node, children):
+        """Abbreviated keyletter name of class"""
+        return { 'keyletter': children[0] }
+
+    def visit_import(self, node, children):
+        """Imported class marker"""
+        d = {'import': children[0]}
+        return d
+
     def visit_class_header(self, node, children):
-        """Beginning of class section, includes name"""
-        abbr = None if len(children) == 1 else children[1]
-        return {'name': children[0], "abbr": abbr}
+        """Beginning of class section, includes name, optional keyletter and optional import marker"""
+        items = {k: v for d in children for k, v in d.items()}
+        return items
 
     def visit_subsystem_header(self, node, children):
         """Beginning of sybsystem section"""
@@ -86,7 +99,7 @@ class SubsystemVisitor(PTNodeVisitor):
     def visit_method_block(self, node, children):
         """Methods (unparsed)"""
         # TODO: Parse these eventually
-        return children  # truncate newline terminator
+        return {"methods": children}
 
     def visit_attr_block(self, node, children):
         """Attribute text (unparsed)"""
@@ -100,7 +113,9 @@ class SubsystemVisitor(PTNodeVisitor):
     def visit_class_block(self, node, children):
         """A complete class with attributes, methods, state model"""
         # TODO: No state models yet
-        return {**children[0], **children[1]}
+        class_attrs = children[0] | children[1]
+        block = class_attrs if len(children) == 2 else class_attrs | children[2]
+        return block
 
     def visit_rel_section(self, node, children):
         """Relationships section with all of the relationships"""
